@@ -11,11 +11,11 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  *
  * SandNetDevice.h
  * Interface for the sandnet device
- * Copyright (C) 2005-2009 Simon Newton
+ * Copyright (C) 2005 Simon Newton
  */
 
 #ifndef PLUGINS_SANDNET_SANDNETDEVICE_H_
@@ -60,8 +60,8 @@ class SandNetDevice: public ola::Device {
     static const char SANDNET_DEVICE_NAME[];
     // the number of input ports to create
     static const unsigned int INPUT_PORTS = 8;
-    // send an advertistment every 2s.
-    static const int ADVERTISTMENT_PERIOD_MS = 2000;
+    // send an advertisement every 2s.
+    static const int ADVERTISEMENT_PERIOD_MS = 2000;
 };
 }  // namespace sandnet
 }  // namespace plugin
