@@ -16,20 +16,32 @@
 # ola_mon.py
 # Copyright (C) 2010 Simon Newton
 
+# TODO(Peter): On Python 2 at least, when you try and exit this with Ctrl+C it
+# doesn't stop
+
+from __future__ import print_function
+
 import getopt
-import httplib
-import rrdtool
-import time
 import os.path
-import signal
+import re
 import socket
 import sys
 import textwrap
 import threading
+import time
+
+import rrdtool
+
+if sys.version_info >= (3, 0):
+  try:
+    import http.client as httplib
+  except ImportError:
+    import httplib
 
 DEFAULT_CONFIG = 'ola_mon.conf'
 DEFAULT_PORT = 9090
 
+
 class OlaFetcher(object):
   def __init__(self, host, port):
     self._host = host
@@ -48,7 +60,7 @@ class OlaFetcher(object):
 
   def _FetchDebug(self):
     """Fetch the contents of the debug page."""
-    connection = httplib.HTTPConnection('%s:%d' %(self._host, self._port))
+    connection = httplib.HTTPConnection('%s:%d' % (self._host, self._port))
     try:
       connection.request('GET', '/debug')
     except socket.error:
@@ -57,7 +69,10 @@ class OlaFetcher(object):
     try:
       response = connection.getresponse()
       if response.status == 200:
-        return response.read()
+        if sys.version_info >= (3, 2):
+          return response.read().decode('utf-8')
+        else:
+          return response.read()
     except httplib.BadStatusLine:
       return None
     return None
@@ -69,13 +84,13 @@ class OlaFetcher(object):
     for line in contents.split('\n'):
       if ':' not in line:
         continue
-      var, data  = line.split(':', 1)
+      var, data = line.split(':', 1)
       var = var.strip()
       data = data.strip()
 
       if data.startswith('map:'):
-        #label, key_values = data.split(' ', 1)
-        #_, label_name = label.split(':', 1)
+        # label, key_values = data.split(' ', 1)
+        # _, label_name = label.split(':', 1)
         pass
       else:
         variables[var] = data
@@ -89,14 +104,13 @@ class RRDStore(object):
 
     data_sources = []
     for type, variable, _ in variables:
-      data_sources.append('DS:%s:%s:30:0:U' % (variable, type))
+      data_sources.append('DS:%s:%s:30:0:U' % (SanitizeName(variable), type))
 
     if not os.path.exists(filename):
       rrdtool.create(filename,
                      '--step=1',
                      data_sources,
                      'RRA:AVERAGE:0.5:1:300')
-                     #'RRA:AVERAGE:0.5:10:300')
 
   def Update(self, timestamp, data):
     args = ['%d' % timestamp]
@@ -111,7 +125,7 @@ class Monitor(threading.Thread):
     threading.Thread.__init__(self)
     self._fetcher = OlaFetcher(host, port)
     rrd_file = os.path.join(rrd_directory, '%s.rrd' % host)
-    self._store = RRDStore(variables, rrd_file);
+    self._store = RRDStore(variables, rrd_file)
     self._terminate = False
 
   def Terminate(self):
@@ -155,10 +169,12 @@ class Grapher(threading.Thread):
                     '--title', title,
                     '--start', 'end-30s',
                     'DEF:%s=%s:%s:AVERAGE' %
-                      (variable, self._rrd_file, variable),
-                    'LINE1:%s#FF0000' % variable)
+                      (SanitizeName(variable),
+                       self._rrd_file,
+                       SanitizeName(variable)),
+                    'LINE1:%s#FF0000' % SanitizeName(variable))
 
-    variables = set([ x for _, x, _ in self._variables])
+    variables = set([SanitizeName(x) for _, x, _ in self._variables])
     for cdef_name, function, title in self._cdefs:
       output_file = os.path.join(self._directory, '%s.png' % cdef_name)
       values = function.split(',')
@@ -166,7 +182,9 @@ class Grapher(threading.Thread):
       defs = []
       for variable in used_variables:
         defs.append('DEF:%s=%s:%s:AVERAGE' %
-                    (variable, self._rrd_file, variable))
+                    (SanitizeName(variable),
+                     self._rrd_file,
+                     SanitizeName(variable)))
 
       rrdtool.graph(output_file,
                     '--imgformat', 'PNG',
@@ -174,10 +192,13 @@ class Grapher(threading.Thread):
                     '--start', 'end-30s',
                     defs,
                     'CDEF:%s=%s' %
-                      (cdef_name, function),
-                    'LINE1:%s#FF0000' % cdef_name)
+                      (SanitizeName(cdef_name), function),
+                    'LINE1:%s#FF0000' % SanitizeName(cdef_name))
 
 
+def SanitizeName(variable):
+  return re.sub("[^a-zA-Z0-9_]", "_", variable)
+
 
 def LoadConfig(config_file):
   """Load the config file.
@@ -189,20 +210,21 @@ def LoadConfig(config_file):
     A dict with the config parameters.
   """
   locals = {}
-  execfile(config_file, {}, locals)
+  # Python 2 and 3 compatible version of execfile
+  exec(open(config_file).read(), {}, locals)
 
   keys = set(['OLAD_SERVERS', 'DATA_DIRECTORY', 'VARIABLES', 'WWW_DIRECTORY',
               'CDEFS'])
   if not keys.issubset(locals.keys()):
-    print 'Invalid config file'
+    print('Invalid config file')
     sys.exit(2)
 
   if not len(locals['OLAD_SERVERS']):
-    print 'No hosts defined'
+    print('No hosts defined')
     sys.exit(2)
 
   if not len(locals['VARIABLES']):
-    print 'No variables defined'
+    print('No variables defined')
     sys.exit(2)
 
   return locals
@@ -210,20 +232,20 @@ def LoadConfig(config_file):
 
 def Usage(binary):
   """Display the usage information."""
-  print textwrap.dedent("""\
+  print(textwrap.dedent("""\
     Usage: %s [options]
 
     Start the OLAD monitoring system
       -h, --help   Display this help message
       -c, --config The config file to use
-    """ % binary)
+    """ % binary))
 
 
 def main():
   try:
     opts, args = getopt.getopt(sys.argv[1:], "hc:v", ["help", "config="])
-  except getopt.GetoptError, err:
-    print str(err)
+  except getopt.GetoptError as e:
+    print(str(e))
     Usage(sys.argv[0])
     sys.exit(2)
 
@@ -262,5 +284,6 @@ def main():
   for thread in threads:
     thread.join()
 
-if __name__ == "__main__":
-      main()
+
+if __name__ == '__main__':
+  main()
